@@ -11,7 +11,7 @@ auto_AUTHNumber.py - The core part of the Author Number library.
 
 Author: Matt Belfast Brown 
 Creat Date:2021-05-30
-Version:1.0.0
+Version:1.0.0.0001
 
 
 THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
@@ -31,7 +31,7 @@ You should have received a copy of the GNU General Public License along with thi
 import author_number as an
 import pypinyin as pn
 
-fetchcode()=an.fun_take_code()
+fetchcode=an.fun_take_code
 
 def get_pronouncation(alte_word):
     pron_ounc=pn.pinyin(alte_word,heteronym=True,style=pn.Style.FIRST_LETTER)
